@echo off
REM *****************************************************
REM *
REM *
REM *	Simple batch file to update firmware and then load in 
REM *	a configuration file into WS500 Alternator Regulators
REM *
REM *	(c) Copyright 2020, TJC Micro
REM *   All Rights Reserved
REM *
REM *
REM *
REM *
REM *
REM *
REM *****************************************************
SETLOCAL ENABLEDELAYEDEXPANSION




REM Set these two varables to the two files you want to use...
REM
SET firmware=WS500-2.2.2
SET configure="FullRiver AGM.txt"






ECHO.
ECHO.
ECHO This simple batch file will upgrade your WS500 Advanced Alternator Regualtor's firmware
ECHO and load a configuration into it.  You will need to remove the top cover of the 
ECHO regulator and connect this computer via a cable to the USB port on the regulator's board.
ECHO.
ECHO The Regulator will update the firmware to version:  !firmware!
ECHO and be loaded with the configuration contained in: !configure!
ECHO.
ECHO.



ECHO.
ECHO.
ECHO First the Firmware will be updated.
ECHO Connect a USB cable to target regulator and computer.
ECHO   (It is best of the regualtor is the ONLY device connected to
ECHO    this comptuer.  If you receive errros, try removing any other
ECHO    device plugged into a USB port and restarting this update batch file)
ECHO.
ECHO Then press-and-hold the RESET button on the regulator for 5 seconds
ECHO.
ECHO Once that is done

PAUSE

ECHO.
ECHO.
ECHO Updating Firmware
ECHO.
ECHO.


dfusecommand -c -d --v --fn !firmware!.dfu

ECHO.
ECHO.
ECHO.
ECHO Finished.
ECHO.
ECHO.
ECHO Verify upgrade completed without errors.  
ECHO.
ECHO Now the configuration will be loaded into the regulator.
ECHO Press-and-release the RESET button on the regulator to return to normal mode.
ECHO.
ECHO Once that is done, count to 5 and then

PAUSE



ECHO.
ECHO Loading configuraton


SET comPort=COM1
if ["%~1"]==[""] (
    ECHO.
    ECHO Scanning USB ports, looking for the regulator.
    ECHO.


	REM **********************************************************
	REM *
	REM *	Scan the COM ports, looking for a list of active ports.
	REM *	When one is found just try calling WS500_transfer and see if
	REM *	it works.
	REM *
	REM **********************************************************
	for /f "tokens=4" %%A in ('mode^|findstr "COM[0-9]*:"') do (

        :: Looks like we may have found one.
        ECHO Going to try uploading to port %%A
	ECHO.
        SET comPort=%%A

        :: Does string have a trailing `:` char? If so remove it 
        IF !comPort:~-1!==: SET comPort=!comPort:~0,-1!

	WS500_transfer -P!comPort!  -f!configure! -v -R

 	)


) else (
    ECHO.
    ECHO.
    ECHO Com port %1 specified, will upload to that port
    ECHO.
    
    SET comPort=%1
    
    :: Does string have a trailing `:` char? If so remove it 
    IF !comPort:~-1!==: SET comPort=!comPort:~0,-1!
    
    WS500_transfer -P!comPort!  -f!configure!  -v -R
)

ECHO.
ECHO.
ECHO.
ECHO Finished.
ECHO.
ECHO.
ECHO Verify the configuration completed without errors and once done 
PAUSE
ECHO.









